# Meal Plan Models

Classes for representing meal plans, meal plan sections, and recipes.

## MealPlanItem

::: grocy.data_models.meal_items.MealPlanItem
    options:
      members_order: source

## MealPlanSection

::: grocy.data_models.meal_items.MealPlanSection
    options:
      members_order: source

## MealPlanItemType

::: grocy.data_models.meal_items.MealPlanItemType
    options:
      members_order: source

## RecipeItem

::: grocy.data_models.meal_items.RecipeItem
    options:
      members_order: source
